==> pochy-0.2-src.tar.gz: pochy-0.2-src/Skin.h <==
#if !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)
#define AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Skin.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CSkin t[


class CSkin
{
private:
	CString m_skinIniFile;

	CString m_tasktrayIcon;
	CString m_tasktrayAnimeIcon;
	CString m_summarryViewIcons;
	CString m_summarryViewBackBmp;
	CString m_folderViewBackBmp;
	CString m_textViewBackBmp;
	CString m_maileditViewBackBmp;
	CString m_headerViewBackBmp;
	CString m_attachedfileViewBackBmp;
 	CString m_multipartViewBackBmp;
	CString m_toolbarDraftIcons;
	CString m_toolbarMainIcons;
	CString m_treeViewIcons;
	CString m_successEffectSound;

protected:

public:
	CSkin();  
	virtual ~CSkin();
	//skin.inĩ[h
	BOOL LoadSkinProfile(char *skinIniFile);
	//lget֐
	CString getSkinIniFile();
	CString getSkinIniPath();

	CString getTasktrayIcon();
	CString getTasktrayAnimeIcon();
	CString getSummarryViewIcons();
	CString getSummarryViewBackBmp();
	CString getFolderViewBackBmp();
	CString getTextViewBackBmp();
	CString getMailEditViewBackBmp();
	CString getHeaderViewBackBmp();
 	CString getAttachedFileViewBackBmp();
 	CString getMultiPartViewBackBmp();
	CString getToolbarDraftIcons();
	CString getToolbarMainIcons();
	CString getTreeViewIcons();
	CString getSuccessEffectSound();
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)

==> pochy-0.2.1a-src.tar.gz: pochy-0.2.1a-src/Skin.h <==
#if !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)
#define AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Skin.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CSkin t[


class CSkin
{
private:
	CString m_skinIniFile;

	CString m_tasktrayIcon;
	CString m_tasktrayAnimeIcon;
	CString m_summarryViewIcons;
	CString m_summarryViewBackBmp;
	CString m_folderViewBackBmp;
	CString m_textViewBackBmp;
	CString m_maileditViewBackBmp;
	CString m_headerViewBackBmp;
	CString m_attachedfileViewBackBmp;
 	CString m_multipartViewBackBmp;
	CString m_toolbarDraftIcons;
	CString m_toolbarMainIcons;
	CString m_treeViewIcons;
	CString m_successEffectSound;

protected:

public:
	CSkin();  
	virtual ~CSkin();
	//skin.inĩ[h
	BOOL LoadSkinProfile(LPCTSTR skinIniFile);
	//lget֐
	CString getSkinIniFile();
	CString getSkinIniPath();

	CString getTasktrayIcon();
	CString getTasktrayAnimeIcon();
	CString getSummarryViewIcons();
	CString getSummarryViewBackBmp();
	CString getFolderViewBackBmp();
	CString getTextViewBackBmp();
	CString getMailEditViewBackBmp();
	CString getHeaderViewBackBmp();
 	CString getAttachedFileViewBackBmp();
 	CString getMultiPartViewBackBmp();
	CString getToolbarDraftIcons();
	CString getToolbarMainIcons();
	CString getTreeViewIcons();
	CString getSuccessEffectSound();
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SKIN_H__F3AA9452_D0EF_424B_9B0E_62D6FFF8404F__INCLUDED_)
